From 4d7869ada3fcac4c09c9a3da9977b3a564bf2c74 Mon Sep 17 00:00:00 2001
From: Mojtaba Samimi <arch.mojtaba.samimi@gmail.com>
Date: Fri, 4 Mar 2022 15:09:43 -0500
Subject: [PATCH] add tests for mathjax reset config & renderer

---
 .circleci/test.sh                             |  6 +-
 .../bundle_tests/mathjax_config_test.js       | 72 +++++++++++++++++++
 2 files changed, 76 insertions(+), 2 deletions(-)
 create mode 100644 test/jasmine/bundle_tests/mathjax_config_test.js

diff --git a/.circleci/test.sh b/.circleci/test.sh
index a7900cfbdf9..ecb9b0649c7 100755
--- a/.circleci/test.sh
+++ b/.circleci/test.sh
@@ -75,8 +75,10 @@ case $1 in
         ;;
 
     mathjax-firefox82+)
-        ./node_modules/karma/bin/karma start test/jasmine/karma.conf.js --FF --skip-tags=noFF82 --bundleTest=mathjax --nowatch &&
-        ./node_modules/karma/bin/karma start test/jasmine/karma.conf.js --FF --skip-tags=noFF82 --bundleTest=mathjax --mathjax3 --nowatch || EXIT_STATE=$?
+        ./node_modules/karma/bin/karma start test/jasmine/karma.conf.js --FF --bundleTest=mathjax --skip-tags=noFF82 --nowatch &&
+        ./node_modules/karma/bin/karma start test/jasmine/karma.conf.js --FF --bundleTest=mathjax --mathjax3 --skip-tags=noFF82 --nowatch &&
+        ./node_modules/karma/bin/karma start test/jasmine/karma.conf.js --FF --bundleTest=mathjax_config --mathjax3 --nowatch &&
+        ./node_modules/karma/bin/karma start test/jasmine/karma.conf.js --FF --bundleTest=mathjax_config --nowatch || EXIT_STATE=$?
         exit $EXIT_STATE
         ;;
 
diff --git a/test/jasmine/bundle_tests/mathjax_config_test.js b/test/jasmine/bundle_tests/mathjax_config_test.js
new file mode 100644
index 00000000000..e43b365cdf5
--- /dev/null
+++ b/test/jasmine/bundle_tests/mathjax_config_test.js
@@ -0,0 +1,72 @@
+/* eslint-disable new-cap */
+
+var Plotly = require('@lib/index');
+
+var createGraphDiv = require('../assets/create_graph_div');
+var destroyGraphDiv = require('../assets/destroy_graph_div');
+var loadScript = require('../assets/load_script');
+
+// eslint-disable-next-line no-undef
+var mathjaxVersion = __karma__.config.mathjaxVersion;
+
+describe('Test MathJax v' + mathjaxVersion + ' config test:', function() {
+    var gd;
+
+    beforeAll(function(done) {
+        gd = createGraphDiv();
+
+        if(mathjaxVersion === 3) {
+            window.MathJax = {
+                startup: {
+                    output: 'chtml',
+                    tex: {
+                        inlineMath: ['|', '|']
+                    }
+                }
+            };
+        }
+
+        var src = mathjaxVersion === 3 ?
+            '/base/node_modules/mathjax-v3/es5/tex-svg.js' :
+            '/base/node_modules/mathjax-v2/MathJax.js?config=TeX-AMS_SVG';
+
+        loadScript(src, done);
+    });
+
+    afterAll(destroyGraphDiv);
+
+    it('should maintain startup renderer & inlineMath after SVG rendering', function(done) {
+        if(mathjaxVersion === 2) {
+            window.MathJax.Hub.Config({
+                tex2jax: {
+                    inlineMath: ['|', '|']
+                }
+            });
+
+            window.MathJax.Hub.setRenderer('CHTML');
+        }
+
+        Plotly.newPlot(gd, {
+            data: [{
+                y: [1, 2]
+            }],
+            layout: {
+                title: {
+                    text: '|E=mc^2|'
+                }
+            }
+        })
+        .then(function() {
+            if(mathjaxVersion === 3) {
+                expect(window.MathJax.config.startup.tex.inlineMath).toEqual(['|', '|']);
+                expect(window.MathJax.config.startup.output).toEqual('chtml');
+            }
+
+            if(mathjaxVersion === 2) {
+                expect(window.MathJax.Hub.config.tex2jax.inlineMath).toEqual(['|', '|']);
+                expect(window.MathJax.Hub.config.menuSettings.renderer).toEqual('');
+            }
+        })
+        .then(done, done.fail);
+    });
+});
